@@ -19,6 +19,7 @@ from sklearn.base import MetaEstimatorMixin
 from sklearn.base import clone
 from sklearn.feature_selection import SelectorMixin
 from sklearn.metrics import check_scoring
+from sklearn.model_selection._search import BaseSearchCV
 from sklearn.model_selection._validation import _score, cross_val_score
 from sklearn.utils.metaestimators import if_delegate_has_method, _safe_split
 from sklearn.utils.validation import check_is_fitted, check_X_y, check_random_state
@@ -62,9 +63,11 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
     Examples
     --------
 
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> bf = BackForward(svr,primary_feature=4, random_state=1)
     >>> new_x = bf.fit_transform(X,y)
@@ -77,9 +80,11 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
     If score and predict is used, the refit could be set True and make sure the data is splited, due to the refit
      used all data in fit() function.
 
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> bf = BackForward(svr,primary_feature=4, random_state=1, refit=True)
     >>> new_x = bf.fit_transform(X[:50],y[:50])
@@ -90,10 +95,12 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
     --------
     If GridSearchCV, the refit could be set True and return the cv score.
 
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
     >>> from sklearn import model_selection
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> gd = model_selection.GridSearchCV(svr,param_grid={"C":[1,10]},n_jobs=1,cv=5)
     >>> bf = BackForward(gd,primary_feature=4, random_state=1, refit=True)
@@ -202,10 +209,10 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
             if self.check_must:
                 slice10 = [_ for _ in slice10 if _ not in self.must_fold_add]
 
-            if len(slice0) <= self.min_type_feature_to_select:
-                pass
-            else:
-                for sub in list(slice10):
+            for sub in list(slice10):
+                if len(slice0) <= self.min_type_feature_to_select:
+                    pass
+                else:
                     slice0.remove(sub)
                     test0 = score(slices=slice0)
                     if test0 > best0 - self.tolerant:
@@ -261,7 +268,7 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
                 estimator_.fit(data_x0, y0)
 
-                if hasattr(estimator_, 'best_score_'):
+                if hasattr(estimator_, 'best_score_') or isinstance(estimator_, BaseSearchCV):
                     score0 = np.mean(estimator_.best_score_)
                 else:
                     score0 = np.mean(cross_val_score(estimator_, data_x0, y0, cv=self.cv))
@@ -396,9 +403,11 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
         Number of cores to run in parallel while fitting across folds.
         ``None`` means 1 and ``-1`` means using all processors.
 
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> bf = BackForwardStable(svr,primary_feature=9,  random_state=1)
     >>> new_x = bf.fit_transform(X,y)
@@ -411,9 +420,11 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
     If score and predict is used, the refit could be set True and make sure the data is splited, due to the refit
     used all data in fit() function.
 
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> bf = BackForwardStable(svr,primary_feature=4, random_state=1, refit=True)
     >>> new_x = bf.fit_transform(X[:50],y[:50])
@@ -422,10 +433,12 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
 
     If GridSearchCV, the refit could be set True and return the cv score.
 
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
     >>> from sklearn import model_selection
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> gd = model_selection.GridSearchCV(svr,param_grid={"C":[1,10]},n_jobs=1,cv=5)
     >>> bf = BackForward(gd,primary_feature=4, random_state=1, refit=True)
@@ -585,11 +598,3 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
     def _get_support_mask(self):
         check_is_fitted(self, 'support_')
         return self.support_
-
-# from sklearn.datasets import load_boston
-# from sklearn.svm import SVR
-# X,y = load_boston(return_X_y=True)
-# svr= SVR()
-# bf = BackForwardCV(svr, primary_feature=9,  random_state=1)
-# new_x = bf.fit_transform(X,y)
-# bf.support_
