@@ -8,11 +8,10 @@ from deap import tools
 from deap.algorithms import varAnd
 from deap.tools import mutShuffleIndexes
 from sklearn.base import BaseEstimator, MetaEstimatorMixin
-from sklearn.datasets import load_boston
 from sklearn.feature_selection import SelectorMixin
 from sklearn.metrics import r2_score
 from sklearn.model_selection import cross_val_score
-from sklearn.svm import SVR
+from sklearn.model_selection._search import BaseSearchCV
 from sklearn.utils.validation import check_is_fitted
 
 from featurebox.selection.mutibase import MutiBase
@@ -144,9 +143,9 @@ class GA(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
     Examples
     ---------
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
-    >>> data = load_boston()
+    >>> data = fetch_california_housing()
     >>> x = data.data[:50]
     >>> y = data.target[:50]
     >>> svr = SVR(gamma="scale", C=100)
@@ -296,7 +295,7 @@ class GA(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
             if hasattr(svr, "max_features"):
                 svr.max_features = x.shape[1]
             svr.fit(x, y)
-            if hasattr(svr, "best_score_"):
+            if hasattr(svr, "best_score_") or isinstance(svr, BaseSearchCV):
                 sc = svr.best_score_
             else:
                 sc = np.mean(cross_val_score(svr, x, y, cv=cv))
@@ -384,13 +383,17 @@ class GA(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
         return score
 
 
-if __name__ == "__main__":
-    data = load_boston()
-    x = data.data
-    y = data.target
-    svr = SVR(gamma="scale", C=100)
-
-    ga = GA(estimator=svr, n_jobs=1, pop_n=100, hof_n=1, cxpb=0.8, mutpb=0.4, ngen=10,
-            max_or_min="max", mut_indpb=0.1, min_=2, muti_index=[0, 5], random_state=0)
-    ga.fit(x, y)
-    ga.score(x, y)
+# if __name__ == "__main__":
+#     from sklearn.svm import SVR
+#     from sklearn.datasets import fetch_california_housing
+#     data = fetch_california_housing()
+#     x = data.data
+#     y = data.target
+#     x = x[:100]
+#     y = y[:100]
+#     svr = SVR(gamma="scale", C=100)
+#
+#     ga = GA(estimator=svr, n_jobs=2, pop_n=100, hof_n=1, cxpb=0.8, mutpb=0.4, ngen=10,
+#             max_or_min="max", mut_indpb=0.1, min_=2, muti_index=[0, 5], random_state=0)
+#     ga.fit(x, y)
+#     ga.score(x, y)
